EnrollResult class
The result of FacePing.enroll.
- Annotations
Constructors
- EnrollResult({required EnrollOutcome outcome, required String id})
-
Creates a result (FacePing creates these; you only need this in tests).
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
The id the face was enrolled under.
final
- isEnrolled → bool
-
True when the face is stored (EnrollOutcome.enrolled).
no setter
- outcome → EnrollOutcome
-
What happened.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override